==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ToolActionButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionButtonDescription } from "./ToolActionButtonDescription";
/**
 * @hidden
 */
export let ToolActionButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionButtonDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionButtonDescriptionMetadata.a == null) {
                ToolActionButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionButtonDescriptionMetadata.c(ToolActionButtonDescriptionMetadata.a);
            }
            if (a.k(ToolActionButtonDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolActionButtonDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionButtonDescriptionMetadata.b(a);
            a.ad("ToolActionButton", () => new ToolActionButtonDescription());
            a.ac("ToolActionButton", ToolActionButtonDescriptionMetadata.a);
        }
    }
    ToolActionButtonDescriptionMetadata.$t = markType(ToolActionButtonDescriptionMetadata, 'ToolActionButtonDescriptionMetadata');
    ToolActionButtonDescriptionMetadata.a = null;
    return ToolActionButtonDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ToolActionButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionButtonDescription } from "./ToolActionButtonDescription";
/**
 * @hidden
 */
export let ToolActionButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionButtonDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionButtonDescriptionMetadata.a == null) {
                ToolActionButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionButtonDescriptionMetadata.c(ToolActionButtonDescriptionMetadata.a);
            }
            if (a.k(ToolActionButtonDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionButtonDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
            a.item("DisplayType", "ExportedType:string:ToolActionButtonDisplayType");
            a.item("DisplayType@names", "Raised;Flat;Outlined");
            a.item("CornerRadius", "Number:double");
        }
        static d(a) {
            ToolActionButtonDescriptionMetadata.b(a);
            a.ae("ToolActionButton", () => new ToolActionButtonDescription());
            a.ad("ToolActionButton", ToolActionButtonDescriptionMetadata.a);
        }
    }
    ToolActionButtonDescriptionMetadata.$t = markType(ToolActionButtonDescriptionMetadata, 'ToolActionButtonDescriptionMetadata');
    ToolActionButtonDescriptionMetadata.a = null;
    return ToolActionButtonDescriptionMetadata;
})();
